@@ -1,6 +1,7 @@
 # benchmark_parser.py
 
 import csv
+import numpy
 
 from .gradle_benchmark import GradleBenchmark
 
@@ -12,8 +13,6 @@ def parse(benchmark_file):
 
             builds = []
             task = ''
-            mean = ''
-            stddev = ''
 
             for row in data:
                 description = row[0]
@@ -22,24 +21,15 @@ def parse(benchmark_file):
                 if 'measured build' in description:
                     builds.append(int(value))
 
-                if 'mean' in description:
-                    mean = float(value)
-
-                if 'stddev' in description:
-                    stddev = float(value)
-
                 if 'tasks' in description:
                     task = value
 
-            if(values_ensured(builds, task, mean,stddev)):
+            if(builds and task):
+                # We now have to calculate mean and stddev by our own since
+                # Gradle Profiler does not report these metrics in the CSV anymore
+                mean = round(numpy.mean(builds), 2)
+                stddev = round(numpy.std(builds), 2)
                 return GradleBenchmark(benchmark_file, task, builds, mean, stddev)
+
     except:
         raise Exception(f"Can't parse benchmarks inputs from {benchmark_file}")
-
-
-def values_ensured(*values):
-    for value in values:
-        if not value:
-            return False
-
-    return True
